import { View, Text, TouchableOpacity, StyleSheet, ToastAndroid} from 'react-native'
import React from 'react'
import { FontAwesome } from "@expo/vector-icons";
import { colors} from "../../../utils/GlobalUtils";

// Component that renders each individual arrow button, which allows user to go to different floors incrementally (either +1 or -1)
// 3 props that are used:   
// 1. propEvent (handles the logic behind either adding 1 or subtracting 1 to change floors ) 
// 2. num (has a value of either +1 or -1, used here to enforce consistent symmetry for styling the button)
// 3. fontAweIcon (name of font awesome icon that's used)

function ArrowButton(props) {
    if (props.num != 0) {
        return (
            <TouchableOpacity style={styles.arrowButton} onPress={props.propEvent} >
              <View style={{ flex: 1, justifyContent: "center", alignItems: "center" }}>
                <FontAwesome style={{ marginLeft: (props.num == 1 ? 5 : -5) }} color={"white"} size={20} name={props.fontAweIcon} />
              </View>
            </TouchableOpacity>
        )
      }
      else {
        return (
          <View style={{ flex: 1.2, marginHorizontal: 7, height: 53.5, maxWidth: 60, borderRadius: 10 }}>
          </View>
        )
      }
  }


const styles = StyleSheet.create({
    arrowButton: {
        flex: 1,
        backgroundColor: colors.red,
        height: 53.5,
        borderRadius: 8,
      },
})



export default ArrowButton